@@ -14,6 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 #
 # Copyright (c) 2013, Michael Komitee
@@ -43,23 +44,23 @@
 import logging
 import os
 from functools import wraps
-from socket import getfqdn
-from typing import Any, Callable, Optional, Tuple, TypeVar, Union, cast
+from typing import Any, Callable, TypeVar, cast
 
 import kerberos
 from flask import Response, _request_ctx_stack as stack, g, make_response, request  # type: ignore
 from requests_kerberos import HTTPKerberosAuth
 
 from airflow.configuration import conf
+from airflow.utils.net import getfqdn
 
 log = logging.getLogger(__name__)
 
 
-CLIENT_AUTH: Optional[Union[Tuple[str, str], Any]] = HTTPKerberosAuth(service='airflow')
+CLIENT_AUTH: tuple[str, str] | Any | None = HTTPKerberosAuth(service="airflow")
 
 
 class KerberosService:
-    """Class to keep information about the Kerberos Service initialized"""
+    """Class to keep information about the Kerberos Service initialized."""
 
     def __init__(self):
         self.service_name = None
@@ -70,18 +71,18 @@ _KERBEROS_SERVICE = KerberosService()
 
 
 def init_app(app):
-    """Initializes application with kerberos"""
-    hostname = app.config.get('SERVER_NAME')
+    """Initialize application with kerberos."""
+    hostname = app.config.get("SERVER_NAME")
     if not hostname:
         hostname = getfqdn()
     log.info("Kerberos: hostname %s", hostname)
 
-    service = 'airflow'
+    service = "airflow"
 
     _KERBEROS_SERVICE.service_name = f"{service}@{hostname}"
 
-    if 'KRB5_KTNAME' not in os.environ:
-        os.environ['KRB5_KTNAME'] = conf.get('kerberos', 'keytab')
+    if "KRB5_KTNAME" not in os.environ:
+        os.environ["KRB5_KTNAME"] = conf.get("kerberos", "keytab")
 
     try:
         log.info("Kerberos init: %s %s", service, hostname)
@@ -94,7 +95,7 @@ def init_app(app):
 
 def _unauthorized():
     """
-    Indicate that authorization is required
+    Indicate that authorization is required.
     :return:
     """
     return Response("Unauthorized", 401, {"WWW-Authenticate": "Negotiate"})
@@ -130,21 +131,21 @@ T = TypeVar("T", bound=Callable)
 
 
 def requires_authentication(function: T):
-    """Decorator for functions that require authentication with Kerberos"""
+    """Decorate functions that require authentication with Kerberos."""
 
     @wraps(function)
     def decorated(*args, **kwargs):
         header = request.headers.get("Authorization")
         if header:
             ctx = stack.top
-            token = ''.join(header.split()[1:])
+            token = "".join(header.split()[1:])
             return_code = _gssapi_authenticate(token)
             if return_code == kerberos.AUTH_GSS_COMPLETE:
                 g.user = ctx.kerberos_user
                 response = function(*args, **kwargs)
                 response = make_response(response)
                 if ctx.kerberos_token is not None:
-                    response.headers['WWW-Authenticate'] = ' '.join(['negotiate', ctx.kerberos_token])
+                    response.headers["WWW-Authenticate"] = " ".join(["negotiate", ctx.kerberos_token])
 
                 return response
             if return_code != kerberos.AUTH_GSS_CONTINUE:
