@@ -15,14 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
+import datetime
 import logging
 import socket
 import string
-import textwrap
 import time
 from functools import wraps
-from typing import TYPE_CHECKING, Callable, Optional, TypeVar, cast
+from typing import TYPE_CHECKING, Callable, TypeVar, cast
 
 from airflow.configuration import conf
 from airflow.exceptions import AirflowConfigException, InvalidStatsNameException
@@ -45,7 +46,7 @@ class TimerProtocol(Protocol):
         ...
 
     def stop(self, send=True):
-        """Stop, and (by default) submit the timer to statsd"""
+        """Stop, and (by default) submit the timer to StatsD"""
         ...
 
 
@@ -65,7 +66,7 @@ class StatsLogger(Protocol):
         """Gauge stat"""
 
     @classmethod
-    def timing(cls, stat: str, dt) -> None:
+    def timing(cls, stat: str, dt: float | datetime.timedelta) -> None:
         """Stats timing"""
 
     @classmethod
@@ -75,7 +76,7 @@ class StatsLogger(Protocol):
 
 class Timer:
     """
-    Timer that records duration, and optional sends to statsd backend.
+    Timer that records duration, and optional sends to StatsD backend.
 
     This class lets us have an accurate timer with the logic in one place (so
     that we don't use datetime math for duration -- it is error prone).
@@ -125,8 +126,8 @@ class Timer:
     # pystatsd and dogstatsd both have a timer class, but present different API
     # so we can't use this as a mixin on those, instead this class is contains the "real" timer
 
-    _start_time: Optional[int]
-    duration: Optional[int]
+    _start_time: int | None
+    duration: int | None
 
     def __init__(self, real_timer=None):
         self.real_timer = real_timer
@@ -178,42 +179,29 @@ class DummyStatsLogger:
 
 # Only characters in the character set are considered valid
 # for the stat_name if stat_name_default_handler is used.
-ALLOWED_CHARACTERS = set(string.ascii_letters + string.digits + '_.-')
+ALLOWED_CHARACTERS = set(string.ascii_letters + string.digits + "_.-")
 
 
 def stat_name_default_handler(stat_name, max_length=250) -> str:
-    """A function that validate the statsd stat name, apply changes to the stat name
+    """A function that validate the StatsD stat name, apply changes to the stat name
     if necessary and return the transformed stat name.
     """
     if not isinstance(stat_name, str):
-        raise InvalidStatsNameException('The stat_name has to be a string')
+        raise InvalidStatsNameException("The stat_name has to be a string")
     if len(stat_name) > max_length:
         raise InvalidStatsNameException(
-            textwrap.dedent(
-                """\
-            The stat_name ({stat_name}) has to be less than {max_length} characters.
-        """.format(
-                    stat_name=stat_name, max_length=max_length
-                )
-            )
+            f"The stat_name ({stat_name}) has to be less than {max_length} characters."
         )
     if not all((c in ALLOWED_CHARACTERS) for c in stat_name):
         raise InvalidStatsNameException(
-            textwrap.dedent(
-                """\
-            The stat name ({stat_name}) has to be composed with characters in
-            {allowed_characters}.
-            """.format(
-                    stat_name=stat_name, allowed_characters=ALLOWED_CHARACTERS
-                )
-            )
+            f"The stat name ({stat_name}) has to be composed with characters in {ALLOWED_CHARACTERS}."
         )
     return stat_name
 
 
 def get_current_handler_stat_name_func() -> Callable[[str], str]:
     """Get Stat Name Handler from airflow.cfg"""
-    return conf.getimport('metrics', 'stat_name_handler') or stat_name_default_handler
+    return conf.getimport("metrics", "stat_name_handler") or stat_name_default_handler
 
 
 T = TypeVar("T", bound=Callable)
@@ -232,7 +220,7 @@ def validate_stat(fn: T) -> T:
                 stat = handler_stat_name_func(stat)
             return fn(_self, stat, *args, **kwargs)
         except InvalidStatsNameException:
-            log.error('Invalid stat name: %s.', stat, exc_info=True)
+            log.exception("Invalid stat name: %s.", stat)
             return None
 
     return cast(T, wrapper)
@@ -244,7 +232,7 @@ class AllowListValidator:
     def __init__(self, allow_list=None):
         if allow_list:
 
-            self.allow_list = tuple(item.strip().lower() for item in allow_list.split(','))
+            self.allow_list = tuple(item.strip().lower() for item in allow_list.split(","))
         else:
             self.allow_list = None
 
@@ -257,7 +245,7 @@ class AllowListValidator:
 
 
 class SafeStatsdLogger:
-    """Statsd Logger"""
+    """StatsD Logger"""
 
     def __init__(self, statsd_client, allow_list_validator=AllowListValidator()):
         self.statsd = statsd_client
@@ -331,10 +319,12 @@ class SafeDogStatsdLogger:
         return None
 
     @validate_stat
-    def timing(self, stat, dt, tags=None):
+    def timing(self, stat, dt: float | datetime.timedelta, tags: list[str] | None = None):
         """Stats timing"""
         if self.allow_list_validator.test(stat):
             tags = tags or []
+            if isinstance(dt, datetime.timedelta):
+                dt = dt.total_seconds()
             return self.dogstatsd.timing(metric=stat, value=dt, tags=tags)
         return None
 
@@ -349,7 +339,7 @@ class SafeDogStatsdLogger:
 
 class _Stats(type):
     factory = None
-    instance: Optional[StatsLogger] = None
+    instance: StatsLogger | None = None
 
     def __getattr__(cls, name):
         if not cls.instance:
@@ -363,55 +353,55 @@ class _Stats(type):
     def __init__(cls, *args, **kwargs):
         super().__init__(cls)
         if cls.__class__.factory is None:
-            is_datadog_enabled_defined = conf.has_option('metrics', 'statsd_datadog_enabled')
-            if is_datadog_enabled_defined and conf.getboolean('metrics', 'statsd_datadog_enabled'):
+            is_datadog_enabled_defined = conf.has_option("metrics", "statsd_datadog_enabled")
+            if is_datadog_enabled_defined and conf.getboolean("metrics", "statsd_datadog_enabled"):
                 cls.__class__.factory = cls.get_dogstatsd_logger
-            elif conf.getboolean('metrics', 'statsd_on'):
+            elif conf.getboolean("metrics", "statsd_on"):
                 cls.__class__.factory = cls.get_statsd_logger
             else:
                 cls.__class__.factory = DummyStatsLogger
 
     @classmethod
     def get_statsd_logger(cls):
-        """Returns logger for statsd"""
+        """Returns logger for StatsD"""
         # no need to check for the scheduler/statsd_on -> this method is only called when it is set
         # and previously it would crash with None is callable if it was called without it.
         from statsd import StatsClient
 
-        stats_class = conf.getimport('metrics', 'statsd_custom_client_path', fallback=None)
+        stats_class = conf.getimport("metrics", "statsd_custom_client_path", fallback=None)
 
         if stats_class:
             if not issubclass(stats_class, StatsClient):
                 raise AirflowConfigException(
-                    "Your custom Statsd client must extend the statsd.StatsClient in order to ensure "
+                    "Your custom StatsD client must extend the statsd.StatsClient in order to ensure "
                     "backwards compatibility."
                 )
             else:
-                log.info("Successfully loaded custom Statsd client")
+                log.info("Successfully loaded custom StatsD client")
 
         else:
             stats_class = StatsClient
 
         statsd = stats_class(
-            host=conf.get('metrics', 'statsd_host'),
-            port=conf.getint('metrics', 'statsd_port'),
-            prefix=conf.get('metrics', 'statsd_prefix'),
+            host=conf.get("metrics", "statsd_host"),
+            port=conf.getint("metrics", "statsd_port"),
+            prefix=conf.get("metrics", "statsd_prefix"),
         )
-        allow_list_validator = AllowListValidator(conf.get('metrics', 'statsd_allow_list', fallback=None))
+        allow_list_validator = AllowListValidator(conf.get("metrics", "statsd_allow_list", fallback=None))
         return SafeStatsdLogger(statsd, allow_list_validator)
 
     @classmethod
     def get_dogstatsd_logger(cls):
-        """Get DataDog statsd logger"""
+        """Get DataDog StatsD logger"""
         from datadog import DogStatsd
 
         dogstatsd = DogStatsd(
-            host=conf.get('metrics', 'statsd_host'),
-            port=conf.getint('metrics', 'statsd_port'),
-            namespace=conf.get('metrics', 'statsd_prefix'),
+            host=conf.get("metrics", "statsd_host"),
+            port=conf.getint("metrics", "statsd_port"),
+            namespace=conf.get("metrics", "statsd_prefix"),
             constant_tags=cls.get_constant_tags(),
         )
-        dogstatsd_allow_list = conf.get('metrics', 'statsd_allow_list', fallback=None)
+        dogstatsd_allow_list = conf.get("metrics", "statsd_allow_list", fallback=None)
         allow_list_validator = AllowListValidator(dogstatsd_allow_list)
         return SafeDogStatsdLogger(dogstatsd, allow_list_validator)
 
@@ -419,11 +409,11 @@ class _Stats(type):
     def get_constant_tags(cls):
         """Get constant DataDog tags to add to all stats"""
         tags = []
-        tags_in_string = conf.get('metrics', 'statsd_datadog_tags', fallback=None)
-        if tags_in_string is None or tags_in_string == '':
+        tags_in_string = conf.get("metrics", "statsd_datadog_tags", fallback=None)
+        if tags_in_string is None or tags_in_string == "":
             return tags
         else:
-            for key_value in tags_in_string.split(','):
+            for key_value in tags_in_string.split(","):
                 tags.append(key_value)
             return tags
 
