@@ -15,16 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """
 An Action Logger module. Singleton pattern has been applied into this module
 so that registered callbacks can be used all through the same python process.
 """
+from __future__ import annotations
 
+import json
 import logging
-from typing import Callable, List
-
-from airflow.utils.session import create_session
+from typing import Callable
 
 
 def register_pre_exec_callback(action_logger):
@@ -68,7 +67,7 @@ def on_pre_execution(**kwargs):
         try:
             callback(**kwargs)
         except Exception:
-            logging.exception('Failed on pre-execution callback using %s', callback)
+            logging.exception("Failed on pre-execution callback using %s", callback)
 
 
 def on_post_execution(**kwargs):
@@ -86,10 +85,10 @@ def on_post_execution(**kwargs):
         try:
             callback(**kwargs)
         except Exception:
-            logging.exception('Failed on post-execution callback using %s', callback)
+            logging.exception("Failed on post-execution callback using %s", callback)
 
 
-def default_action_log(log, **_):
+def default_action_log(sub_command, user, task_id, dag_id, execution_date, host_name, full_command, **_):
     """
     A default action logger callback that behave same as www.utils.action_logging
     which uses global session and pushes log ORM object.
@@ -98,15 +97,36 @@ def default_action_log(log, **_):
     :param **_: other keyword arguments that is not being used by this function
     :return: None
     """
+    from airflow.models.log import Log
+    from airflow.utils import timezone
+    from airflow.utils.session import create_session
+
     try:
         with create_session() as session:
-            session.add(log)
+            extra = json.dumps({"host_name": host_name, "full_command": full_command})
+            # Use bulk_insert_mappings here to avoid importing all models (which using the classes does) early
+            # on in the CLI
+            session.bulk_insert_mappings(
+                Log,
+                [
+                    {
+                        "event": f"cli_{sub_command}",
+                        "task_instance": None,
+                        "owner": user,
+                        "extra": extra,
+                        "task_id": task_id,
+                        "dag_id": dag_id,
+                        "execution_date": execution_date,
+                        "dttm": timezone.utcnow(),
+                    }
+                ],
+            )
     except Exception as error:
         logging.warning("Failed to log action with %s", error)
 
 
-__pre_exec_callbacks = []  # type: List[Callable]
-__post_exec_callbacks = []  # type: List[Callable]
+__pre_exec_callbacks: list[Callable] = []
+__post_exec_callbacks: list[Callable] = []
 
 # By default, register default action log into pre-execution callback
 register_pre_exec_callback(default_action_log)
